@@ -1,8 +1,8 @@
 #include <math.h>
 #include <algorithm>
 #include "PerPixelMesh.hpp"
-#include "../omptl/omptl"
-#include "../omptl/omptl_algorithm"
+#include "../omptl/omptl"  // EDIT BY SJ
+#include "../omptl/omptl_algorithm"  // EDIT BY SJ
 
 PerPixelMesh::PerPixelMesh(int width, int height) : width(width), height(height), size (width * height),
 		p(width * height, PixelPoint(0,0)),
