@@ -177,8 +177,7 @@ void SjCoverBrowser::OnMouseSelect(wxMouseEvent& event)
 	}
 	else if( found == FOUND_COVER_ARROW )
 	{
-		wxCommandEvent cmd(wxEVT_COMMAND_MENU_SELECTED, IDT_WORKSPACE_SHOW_COVERS);
-		g_mainFrame->GetEventHandler()->AddPendingEvent(cmd);
+		g_mainFrame->GetEventHandler()->QueueEvent(new wxCommandEvent(wxEVT_COMMAND_MENU_SELECTED, IDT_WORKSPACE_SHOW_COVERS));
 	}
 	else if( g_mainFrame->m_columnMixer.IsAnythingSelected() )
 	{
@@ -217,7 +216,6 @@ void SjCoverBrowser::OnMouseLeftUp(wxMouseEvent& event)
 	// dragscroll: restore cursor if changed by dragscroll
 	if( m_window->m_mouseAction == SJ_ACTION_DRAGSCROLL )
 	{
-		m_window->SetCursor(SjVirtKeybdModule::GetStandardCursor());
 		m_window->m_mouseAction = SJ_ACTION_NONE;
 		return; // done
 	}
@@ -242,7 +240,6 @@ void SjCoverBrowser::OnMouseCaptureLost(wxMouseCaptureLostEvent& event)
 	// dragscroll: restore cursor if changed by dragscroll
 	if( m_window->m_mouseAction == SJ_ACTION_DRAGSCROLL )
 	{
-		m_window->SetCursor(SjVirtKeybdModule::GetStandardCursor());
 		m_window->m_mouseAction = SJ_ACTION_NONE;
 		return; // done
 	}
@@ -360,7 +357,6 @@ void SjCoverBrowser::OnMouseMotion(wxMouseEvent& event)
 				// start dragscroll
 				m_window->m_mouseAction = SJ_ACTION_DRAGSCROLL;
 				m_dragscrollCurrY       = yPos;
-				m_window->SetCursor(g_tools->m_staticMovehandCursor);
 			}
 		}
 	}
@@ -463,14 +459,15 @@ void SjCoverBrowser::OnMouseMotion(wxMouseEvent& event)
 
 void SjCoverBrowser::OnMouseWheel(wxMouseEvent& event, bool scrollVert)
 {
-	long zDelta = event.GetWheelRotation();
-	long wheelDelta = event.GetWheelDelta();
-
-	// scroll!
-	if( scrollVert && wheelDelta>0 )
+	if( scrollVert )
 	{
-		OnVScroll(IDT_WORKSPACE_V_SCROLL, m_applRowIndex + (zDelta*-1 /* *m_coversYCount */)/wheelDelta, TRUE/*redraw*/);
-		//                  ^^^ may be used to scroll one page - but I think this is too much
+		// add multiple small rotations (smaller than the delta to take action) to bigger ones
+		static SjWheelHelper s_coverBrowserWheelHelper;
+		long rotateCovers, dir; s_coverBrowserWheelHelper.PushRotationNPopAction(event, rotateCovers, dir);
+		if( rotateCovers != 0 )
+		{
+			OnVScroll(IDT_WORKSPACE_V_SCROLL, m_applRowIndex + rotateCovers*dir*-1, TRUE/*redraw*/);
+		}
 	}
 }
 
@@ -491,12 +488,9 @@ void SjCoverBrowser::OnDropImage(SjDataObject* data, int mouseX, int mouseY)
 }
 
 
-void SjCoverBrowser::OnContextMenu(wxMouseEvent& event)
+void SjCoverBrowser::OnContextMenu(int clickX, int clickY)
 {
 	SjMenu  mainMenu(0);
-	int    clickX = event.GetX();
-	int    clickY = event.GetY();
-	bool   prependOpen = false;
 	SjCol* cover;
 	long found = FindCover(clickX, clickY, &cover);
 	if( found == FOUND_COVER && cover->m_rowCount > 0 && cover->m_rows[0]->m_roughType == SJ_RRTYPE_COVER )
@@ -515,27 +509,39 @@ void SjCoverBrowser::OnContextMenu(wxMouseEvent& event)
 	else
 	{
 		m_lastClickedCover = NULL;
-		if( g_mainFrame->IsAllAvailable() )
-		{
-			mainMenu.Append(IDO_SELECTALL);
-		}
-		prependOpen = true;
 	}
 
 	// add main items to menu
-	g_mainFrame->CreateContextMenu_(mainMenu, prependOpen);
+	g_mainFrame->CreateContextMenu_(mainMenu);
 
 	// show menu
 	if( mainMenu.GetMenuItemCount() )
 	{
-		m_window->PopupMenu(&mainMenu, clickX, clickY);
+		m_window->PopupMenu(&mainMenu);
 	}
 }
 
 
+#define IDC_L_FIRST                  (IDM_LASTPRIVATE-17) // range start
+#define IDC_L_SHOWLEADARTISTNAME     (IDM_LASTPRIVATE-12)
+#define IDC_L_SHOWALBUMNAME          (IDM_LASTPRIVATE-8)
+#define IDC_L_SHOWYEAR               (IDM_LASTPRIVATE-5)
+#define IDC_L_LAST                   (IDM_LASTPRIVATE-1) // range end
+
+
 void SjCoverBrowser::OnContextMenuSelect(int id)
 {
-	if( m_lastClickedCover )
+	if( id >= IDC_L_FIRST && id <= IDC_L_LAST )
+	{
+		long flags = g_mainFrame->m_libraryModule->GetFlags();
+		if( id == IDC_L_SHOWLEADARTISTNAME )     { SjTools::ToggleFlag(flags, SJ_LIB_SHOWLEADARTISTNAME); }
+		if( id == IDC_L_SHOWALBUMNAME )          { SjTools::ToggleFlag(flags, SJ_LIB_SHOWALBUMNAME); }
+		if( id == IDC_L_SHOWYEAR )               { SjTools::ToggleFlag(flags, SJ_LIB_SHOWYEAR); }
+		g_mainFrame->m_libraryModule->SetFlags(flags);
+		g_mainFrame->m_browser->RefreshAll();
+		UpdateItemsInColMenu(g_mainFrame->m_viewMenu);
+	}
+	else if( m_lastClickedCover )
 	{
 		m_lastClickedCover->m_rows[0]->OnContextMenu(id);
 	}
@@ -590,7 +596,9 @@ wxString SjCoverBrowser::GetToolTipText(int mouseX, int mouseY, long &flags)
 	else
 	{
 		if( found == FOUND_COVER_ARROW  )
-			retString = _("Show album name");
+		{
+			retString = _("Show cover titles");
+		}
 
 		m_lastTooltipCover = NULL;
 	}
@@ -600,6 +608,26 @@ wxString SjCoverBrowser::GetToolTipText(int mouseX, int mouseY, long &flags)
 }
 
 
+void SjCoverBrowser::AddItemsToColMenu(SjMenu* m)
+{
+	m->AppendSeparator();
+	m->AppendCheckItem(IDC_L_SHOWLEADARTISTNAME,     _("Artist"));
+	m->AppendCheckItem(IDC_L_SHOWALBUMNAME,          _("Album"));
+	m->AppendCheckItem(IDC_L_SHOWYEAR,               _("Year"));
+
+	UpdateItemsInColMenu(m);
+}
+
+
+void SjCoverBrowser::UpdateItemsInColMenu(SjMenu* m)
+{
+	long flags = g_mainFrame->m_libraryModule->GetFlags();
+	m->Check(IDC_L_SHOWLEADARTISTNAME,     (flags&SJ_LIB_SHOWLEADARTISTNAME)!=0);
+	m->Check(IDC_L_SHOWALBUMNAME,          (flags&SJ_LIB_SHOWALBUMNAME)!=0);
+	m->Check(IDC_L_SHOWYEAR,               (flags&SJ_LIB_SHOWYEAR)!=0);
+}
+
+
 long SjCoverBrowser::FindCover(long xPos, long yPos, SjCol** retCover, wxRect* retRect)
 {
 	int     c;
@@ -973,9 +1001,7 @@ bool SjCoverBrowser::GotoUrl(const wxString& url)
 		delete col;
 
 		// check index
-		#ifdef __WXDEBUG__
 		col = NULL;
-		#endif
 		if( colIndex >= 0 )
 		{
 			// goto column
@@ -1072,9 +1098,7 @@ void SjCoverBrowser::GotoPos(const wxString& guid, long viewOffset)
 		delete col;
 
 		// check index
-		#ifdef __WXDEBUG__
 		col = NULL;
-		#endif
 		if( colIndex >= 0 )
 		{
 			// goto column
