@@ -30,7 +30,7 @@
 #define __SJ_CONFIG_H__
 
 #define SJ_VERSION_MAJOR    16      // when changing the version number here, also change it in configure.ac and maybe in the OS-depending installer
-#define SJ_VERSION_MINOR    2
+#define SJ_VERSION_MINOR    5
 #define SJ_VERSION_REVISION 3
 
 #ifndef SJ_PROGRAM_NAME
@@ -53,6 +53,10 @@
 #define SJ_USE_PROJECTM 1
 #endif
 
+#ifndef SJ_USE_UPNP                 // Use UPNP stuff (requires libupnp and pthreads)
+#define SJ_USE_UPNP 1
+#endif
+
 #ifndef SJ_CAN_USE_MM_KEYBD
 #define SJ_CAN_USE_MM_KEYBD 0       // Can the multimedia keyboards keys be used?
 #endif
