@@ -312,10 +312,9 @@ public:
 
 	// Still configuration.  Load the modules before using the following functions.
 	virtual wxWindow* GetConfigPage       (wxWindow* parent, int selectedPage) { return NULL; }
-	virtual void    GetConfigButtons    (wxString& okText, wxString& cancelText, bool& okBold) { okText=_("OK"); cancelText=_("Cancel"); okBold=FALSE; }
-	#define         SJ_CONFIGPAGE_DONE_GENERIC          0
+	#define         SJ_CONFIGPAGE_DONE_GENERIC          0 // deprecated, no longer send
 	#define         SJ_CONFIGPAGE_DONE_OK_CLICKED       1
-	#define         SJ_CONFIGPAGE_DONE_CANCEL_CLICKED   2
+	#define         SJ_CONFIGPAGE_DONE_CANCEL_CLICKED   2 // deprecated, no longer send
 	virtual void    DoneConfigPage      (wxWindow* configPage, int action) { }
 	int             m_notebookPage;     // used by the settings dialog to remember the current page if a notebook is present
 
@@ -548,7 +547,7 @@ public:
 
 	// get/set sources (eg. directories or servers)
 	virtual long        GetSourceCount      () = 0;
-	virtual wxString    GetSourceUrl        (long index) = 0;
+	virtual wxString    GetSourceUrl        (long index) = 0; // any URL, used for displaying and sorting, not saved; there is no need, the URL is valid, however, it should be unique
 	virtual wxString    GetSourceNotes      (long index) = 0;
 	virtual SjIcon      GetSourceIcon       (long index) = 0;
 	virtual long        AddSources          (int sourceType, wxWindow* parent) = 0; // the function returns the first new index or -1 for errors or abort
@@ -608,6 +607,9 @@ public:
 	// AddVisData() function is called from without the audio DSP output, so please be fast and do not do
 	// weird things here!
 	virtual void    AddVisData          (const float* buffer, long bytes) {}
+
+	// Used to find out a window that can be used as a parent for the overlay.
+	virtual wxWindow* GetSuitableParentForOverlay() = 0;
 };
 
 
@@ -711,12 +713,8 @@ public:
 	#define         SJ_EXT_MUSICFILES           0x001
 	#define         SJ_EXT_IMAGEFILES           0x002
 	#define         SJ_EXT_ARCHIVES             0x004
-	#define         SJ_EXT_SKINFILES            0x008
-	#define         SJ_EXT_LANGUAGEFILES        0x010
-	#define         SJ_EXT_DATABASES            0x020
 	#define         SJ_EXT_PLAYLISTS_READ       0x040
 	#define         SJ_EXT_PLAYLISTS_WRITE      0x080
-	#define         SJ_EXT_KARAOKE              0x100
 	SjExtList       GetAssignedExt              (long flags);
 
 	// searching modules
