@@ -85,6 +85,7 @@ private:
 	wxCheckBox*     m_readHiddenDirsCheckBox;
 	wxCheckBox*     m_readZipCheckBox;
 	wxCheckBox*     m_readId3CheckBox;
+	wxTextCtrl*     m_additionalExtTextCtrl;
 	wxTextCtrl*     m_ignoreExtTextCtrl;
 	wxTextCtrl*     m_infoMaskTextCtrl;
 
@@ -109,7 +110,7 @@ END_EVENT_TABLE()
 
 
 SjFolderSettingsDialog::SjFolderSettingsDialog(SjFolderScannerModule* folderScannerModule, SjFolderScannerSource* source, wxWindow* parent)
-	: SjDialog(parent, wxT(""), SJ_MODAL, SJ_RESIZEABLE_IF_POSSIBLE)
+	: SjDialog(parent, "", SJ_MODAL, SJ_RESIZEABLE_IF_POSSIBLE)
 {
 	// init dialog
 	m_initDone = FALSE;
@@ -133,7 +134,22 @@ SjFolderSettingsDialog::SjFolderSettingsDialog(SjFolderScannerModule* folderScan
 	m_enabledCheckBox->SetValue(source->m_flags&SJ_FOLDERSCANNER_ENABLED? TRUE : FALSE);
 	sizer3->Add(m_enabledCheckBox, 0, wxALIGN_CENTER_VERTICAL);
 
+	// read ID3-Tags?
+	m_readId3CheckBox = new wxCheckBox(this, -1, _("Read (ID3)-tags"));
+	m_readId3CheckBox->SetValue(source->m_flags&SJ_FOLDERSCANNER_READID3? TRUE : FALSE);
+	sizer2->Add(m_readId3CheckBox, 0, wxLEFT|wxRIGHT|wxTOP|wxBOTTOM, SJ_DLG_SPACE);
+
+	// file mask combobox
+	sizer2->Add(new wxStaticText(this, -1,  _("Path and file pattern for track-information if (ID3-)tags are missing:")), 0, wxLEFT|wxRIGHT, SJ_DLG_SPACE);
+
+	m_infoMaskTextCtrl = new wxTextCtrl(this, -1, source->m_trackInfoMatcher.GetPattern());
+	sizer2->Add(m_infoMaskTextCtrl, 0, wxLEFT|wxRIGHT|wxGROW, SJ_DLG_SPACE);
+
+	wxStaticText* staticText = new wxStaticText(this, -1, "("+wxString(_("Placeholders:"))+" <Nr>, <Title>, <Artist>, <Album>, <Genre>, <Group>, <Year>)");
+	sizer2->Add(staticText, 0, wxLEFT|wxRIGHT|wxBOTTOM, SJ_DLG_SPACE);
+
 	// ignore ext combobox
+	m_additionalExtTextCtrl = NULL;
 	m_ignoreExtTextCtrl = NULL;
 	m_doUpdateCheckBox = NULL;
 	m_readHiddenFilesCheckBox = NULL;
@@ -141,59 +157,42 @@ SjFolderSettingsDialog::SjFolderSettingsDialog(SjFolderScannerModule* folderScan
 	m_readZipCheckBox = NULL;
 	if( isDir )
 	{
-		sizer2->Add(new wxStaticText(this, -1,
-		                             _("Ignore music-files and images with the following extensions:")), 0, wxLEFT|wxTOP|wxRIGHT, SJ_DLG_SPACE);
-
-		m_ignoreExtTextCtrl = new wxTextCtrl(this, -1, source->m_ignoreExt.GetExt());
-		sizer2->Add(m_ignoreExtTextCtrl, 0, wxLEFT|wxRIGHT|wxGROW, SJ_DLG_SPACE);
-
-		wxStaticText* staticText = new wxStaticText(this, -1,
-		        _("(separate the extensions using the comma, case is ignored)"));
-		sizer2->Add(staticText, 0, wxLEFT|wxRIGHT|wxBOTTOM, SJ_DLG_SPACE);
-
 		m_doUpdateCheckBox = new wxCheckBox(this, -1, _("Include folder to the update process"));
 		m_doUpdateCheckBox->SetValue(source->m_flags&SJ_FOLDERSCANNER_DOUPDATE? TRUE : FALSE);
 		sizer2->Add(m_doUpdateCheckBox, 0, wxLEFT|wxTOP|wxRIGHT, SJ_DLG_SPACE);
-		sizer2->Add(SJ_DLG_SPACE, SJ_DLG_SPACE/2); // some space
+		sizer2->Add(SJ_DLG_SPACE, SJ_DLG_SPACE/2);
 
-		// only implemented and usefull for MSW - esp for
-		// reading hidden covers from the WMP
 		m_readHiddenFilesCheckBox = new wxCheckBox(this, -1, _("Read hidden files"));
 		m_readHiddenFilesCheckBox->SetValue(source->m_flags&SJ_FOLDERSCANNER_READHIDDENFILES? TRUE : FALSE);
 		sizer2->Add(m_readHiddenFilesCheckBox, 0, wxLEFT|wxRIGHT, SJ_DLG_SPACE);
-		sizer2->Add(SJ_DLG_SPACE, SJ_DLG_SPACE/2); // some space
+		sizer2->Add(SJ_DLG_SPACE, SJ_DLG_SPACE/2);
 
 		m_readHiddenDirsCheckBox = new wxCheckBox(this, -1, _("Read hidden folders"));
 		m_readHiddenDirsCheckBox->SetValue(source->m_flags&SJ_FOLDERSCANNER_READHIDDENDIRS? TRUE : FALSE);
 		sizer2->Add(m_readHiddenDirsCheckBox, 0, wxLEFT|wxRIGHT, SJ_DLG_SPACE);
-		sizer2->Add(SJ_DLG_SPACE, SJ_DLG_SPACE/2); // some space
+		sizer2->Add(SJ_DLG_SPACE, SJ_DLG_SPACE/2);
 
 		m_readZipCheckBox = new wxCheckBox(this, -1, _("Read inside ZIP-/TAR-archives"));
 		m_readZipCheckBox->SetValue(source->m_flags&SJ_FOLDERSCANNER_READZIP? TRUE : FALSE);
-		sizer2->Add(m_readZipCheckBox, 0, wxLEFT|wxRIGHT, SJ_DLG_SPACE);
-		sizer2->Add(SJ_DLG_SPACE, SJ_DLG_SPACE/2); // some space
+		sizer2->Add(m_readZipCheckBox, 0, wxLEFT|wxRIGHT|wxBOTTOM, SJ_DLG_SPACE);
+
+		wxFlexGridSizer* sizer2f = new wxFlexGridSizer(2, 0, SJ_DLG_SPACE/2);
+		sizer2f->AddGrowableCol(0);
+		sizer2f->AddGrowableCol(1);
+		sizer2->Add(sizer2f, 0, wxLEFT|wxRIGHT|wxGROW, SJ_DLG_SPACE);
+
+			sizer2f->Add(new wxStaticText(this, -1, _("Additional file extensions:")), 0, wxGROW, SJ_DLG_SPACE);
+			sizer2f->Add(new wxStaticText(this, -1, _("Ignore file extensions:")), 0, wxGROW, SJ_DLG_SPACE);
+
+			m_additionalExtTextCtrl = new wxTextCtrl(this, -1, source->m_additionalExt.GetExt());
+			sizer2f->Add(m_additionalExtTextCtrl, 0, wxGROW, SJ_DLG_SPACE);
+
+			m_ignoreExtTextCtrl = new wxTextCtrl(this, -1, source->m_ignoreExt.GetExt());
+			sizer2f->Add(m_ignoreExtTextCtrl, 0, wxGROW, SJ_DLG_SPACE);
+
+		wxStaticText* staticText = new wxStaticText(this, -1, _("(separate the extensions using the comma, case is ignored)"));
+		sizer2->Add(staticText, 0, wxLEFT|wxRIGHT|wxBOTTOM, SJ_DLG_SPACE);
 	}
-	else
-	{
-		sizer2->Add(SJ_DLG_SPACE, SJ_DLG_SPACE/2); // some space
-	}
-
-	// read ID3-Tags?
-	m_readId3CheckBox = new wxCheckBox(this, -1, _("Read (ID3)-tags"));
-	m_readId3CheckBox->SetValue(source->m_flags&SJ_FOLDERSCANNER_READID3? TRUE : FALSE);
-	sizer2->Add(m_readId3CheckBox, 0, wxLEFT|wxRIGHT, SJ_DLG_SPACE);
-	sizer2->Add(SJ_DLG_SPACE, SJ_DLG_SPACE/2); // some space
-
-	// file mask combobox
-	sizer2->Add(new wxStaticText(this, -1,
-	                             _("Path and file pattern for track-information if (ID3-)tags are missing:")), 0, wxLEFT|wxTOP|wxRIGHT, SJ_DLG_SPACE);
-
-	m_infoMaskTextCtrl = new wxTextCtrl(this, -1, source->m_trackInfoMatcher.GetPattern());
-	sizer2->Add(m_infoMaskTextCtrl, 0, wxLEFT|wxRIGHT|wxGROW, SJ_DLG_SPACE);
-
-	wxStaticText* staticText = new wxStaticText(this, -1,
-	        wxT("(")+wxString(_("Placeholders:"))+wxT(" <Nr>, <Title>, <Artist>, <Album>, <Genre>, <Group>, <Year>)"));
-	sizer2->Add(staticText, 0, wxLEFT|wxRIGHT|wxBOTTOM, SJ_DLG_SPACE);
 
 	// reset button
 	wxButton* button = new wxButton(this, IDC_RESET, _("Reset to default values"), wxDefaultPosition, wxDefaultSize, wxBU_EXACTFIT);
@@ -204,7 +203,7 @@ SjFolderSettingsDialog::SjFolderSettingsDialog(SjFolderScannerModule* folderScan
 		AddStateBox(sizer1);
 
 		long trackCount = folderScannerModule->GetTrackCount__(source);
-		AddState(_("Track count")+wxString(wxT(":")), trackCount>-1? SjTools::FormatNumber(trackCount) : wxString(_("n/a")));
+		AddState(_("Track count")+wxString(":"), trackCount>-1? SjTools::FormatNumber(trackCount) : wxString(_("n/a")));
 	}
 
 	// buttons
@@ -252,9 +251,14 @@ void SjFolderSettingsDialog::EnableDisable()
 
 void SjFolderSettingsDialog::OnReset(wxCommandEvent&)
 {
+	if( m_additionalExtTextCtrl )
+	{
+		m_additionalExtTextCtrl->SetValue("");
+	}
+
 	if( m_ignoreExtTextCtrl )
 	{
-		m_ignoreExtTextCtrl->SetValue(wxT(""));
+		m_ignoreExtTextCtrl->SetValue("");
 	}
 
 	if( m_doUpdateCheckBox )
@@ -350,7 +354,17 @@ bool SjFolderScannerModule::ConfigSource(long index, wxWindow* parent)
 		needsDeepUpdate = TRUE;
 	}
 
-	// check ignore extension
+	// check additional/ignore extension
+	if( dlg.m_additionalExtTextCtrl )
+	{
+		SjExtList newAdditionalExt(dlg.m_additionalExtTextCtrl->GetValue());
+		if( newAdditionalExt != currSourceObj->m_additionalExt )
+		{
+			currSourceObj->m_additionalExt = newAdditionalExt;
+			needsUpdate = TRUE;
+		}
+	}
+
 	if( dlg.m_ignoreExtTextCtrl )
 	{
 		SjExtList newIgnoreExt(dlg.m_ignoreExtTextCtrl->GetValue());
@@ -373,7 +387,7 @@ bool SjFolderScannerModule::ConfigSource(long index, wxWindow* parent)
 	if( needsDeepUpdate )
 	{
 		wxSqlt sql;
-		sql.ConfigWrite(wxT("folderscanner/deepupdate/")+currSourceObj->UrlPlusFile(), 1);
+		sql.ConfigWrite("folderscanner/deepupdate/"+currSourceObj->UrlPlusFile(), 1);
 	}
 
 	// done so far
@@ -391,7 +405,7 @@ bool SjFolderScannerModule::ConfigSource(long index, wxWindow* parent)
 SjFolderScannerModule::SjFolderScannerModule(SjInterfaceBase* interf)
 	: SjScannerModule(interf)
 {
-	m_file                  = wxT("memory:folderscanner.lib");
+	m_file                  = "memory:folderscanner.lib";
 	m_sort                  = 0; // start of list
 	m_name                  = _("Read files and folders");
 
@@ -412,24 +426,25 @@ void SjFolderScannerModule::LoadSettings__()
 	m_listOfSources.Clear();
 	wxSqlt sql;
 
-	int                     sourceCount = sql.ConfigRead(wxT("folderscanner/sourceCount"), 0L);
+	int                     sourceCount = sql.ConfigRead("folderscanner/sourceCount", 0L);
 	int                     currSourceIndex;
 	wxString                currSourceStr;
 	SjFolderScannerSource*  currSourceObj;
 	for( currSourceIndex = 0; currSourceIndex < sourceCount; currSourceIndex++ )
 	{
-		currSourceStr = sql.ConfigRead(wxString::Format(wxT("folderscanner/url%i"), (int)currSourceIndex), wxT(""));
+		currSourceStr = sql.ConfigRead(wxString::Format("folderscanner/url%i", (int)currSourceIndex), "");
 		if( !currSourceStr.IsEmpty() )
 		{
 			currSourceStr = SjTools::EnsureTrailingSlash(currSourceStr);
 			currSourceObj = new SjFolderScannerSource;
 			if( currSourceObj )
 			{
-				currSourceObj->m_url        = currSourceStr;
-				currSourceObj->m_file       = sql.ConfigRead(wxString::Format(wxT("folderscanner/file%i"), (int)currSourceIndex), wxT(""));
-				currSourceObj->m_ignoreExt  = sql.ConfigRead(wxString::Format(wxT("folderscanner/ignoreExt%i"), (int)currSourceIndex), wxT(""));
-				currSourceObj->m_trackInfoMatcher.Compile(SJ_TI_URL, sql.ConfigRead(wxString::Format(wxT("folderscanner/pattern%i"), (int)currSourceIndex), SjTrackInfoMatcher::GetDefaultPattern()));
-				currSourceObj->m_flags      =  sql.ConfigRead(wxString::Format(wxT("folderscanner/flags%i"), (int)currSourceIndex), SJ_FOLDERSCANNER_DEFFLAGS);
+				currSourceObj->m_url           = currSourceStr;
+				currSourceObj->m_file          = sql.ConfigRead(wxString::Format("folderscanner/file%i", (int)currSourceIndex), "");
+				currSourceObj->m_additionalExt = sql.ConfigRead(wxString::Format("folderscanner/additionalExt%i", (int)currSourceIndex), "");
+				currSourceObj->m_ignoreExt     = sql.ConfigRead(wxString::Format("folderscanner/ignoreExt%i", (int)currSourceIndex), "");
+				currSourceObj->m_trackInfoMatcher.Compile(SJ_TI_URL, sql.ConfigRead(wxString::Format("folderscanner/pattern%i", (int)currSourceIndex), SjTrackInfoMatcher::GetDefaultPattern()));
+				currSourceObj->m_flags         =  sql.ConfigRead(wxString::Format("folderscanner/flags%i", (int)currSourceIndex), SJ_FOLDERSCANNER_DEFFLAGS);
 				m_listOfSources.Append(currSourceObj);
 			}
 		}
@@ -443,7 +458,7 @@ void SjFolderScannerModule::SaveSettings__()
 	wxSqlt sql;
 
 	int sourceCount = m_listOfSources.GetCount();
-	sql.ConfigWrite(wxT("folderscanner/sourceCount"), (long)sourceCount);
+	sql.ConfigWrite("folderscanner/sourceCount", (long)sourceCount);
 
 	SjFolderScannerSourceList::Node* currSourceNode = m_listOfSources.GetFirst();
 	SjFolderScannerSource*           currSourceObj;
@@ -453,11 +468,12 @@ void SjFolderScannerModule::SaveSettings__()
 		// write source
 		currSourceObj = currSourceNode->GetData();
 		wxASSERT(currSourceObj);
-		sql.ConfigWrite(wxString::Format(wxT("folderscanner/url%i"), (int)currSourceIndex), currSourceObj->m_url);
-		sql.ConfigWrite(wxString::Format(wxT("folderscanner/file%i"), (int)currSourceIndex), currSourceObj->m_file);
-		sql.ConfigWrite(wxString::Format(wxT("folderscanner/ignoreExt%i"), (int)currSourceIndex), currSourceObj->m_ignoreExt.GetExt());
-		sql.ConfigWrite(wxString::Format(wxT("folderscanner/pattern%i"), (int)currSourceIndex), currSourceObj->m_trackInfoMatcher.GetPattern());
-		sql.ConfigWrite(wxString::Format(wxT("folderscanner/flags%i"), (int)currSourceIndex), currSourceObj->m_flags);
+		sql.ConfigWrite(wxString::Format("folderscanner/url%i", (int)currSourceIndex), currSourceObj->m_url);
+		sql.ConfigWrite(wxString::Format("folderscanner/file%i", (int)currSourceIndex), currSourceObj->m_file);
+		sql.ConfigWrite(wxString::Format("folderscanner/additionalExt%i", (int)currSourceIndex), currSourceObj->m_additionalExt.GetExt());
+		sql.ConfigWrite(wxString::Format("folderscanner/ignoreExt%i", (int)currSourceIndex), currSourceObj->m_ignoreExt.GetExt());
+		sql.ConfigWrite(wxString::Format("folderscanner/pattern%i", (int)currSourceIndex), currSourceObj->m_trackInfoMatcher.GetPattern());
+		sql.ConfigWrite(wxString::Format("folderscanner/flags%i", (int)currSourceIndex), currSourceObj->m_flags);
 
 		// next source
 		currSourceIndex++;
@@ -468,20 +484,21 @@ void SjFolderScannerModule::SaveSettings__()
 	while( 1 /*exit by break*/ )
 	{
 		#define MAX_DEL 1000
-		if( sql.ConfigRead(wxString::Format(wxT("folderscanner/url%i"), (int)currSourceIndex), wxT("*"))==wxT("*") /*check for existance (`*` is an invalid URL)*/
+		if( sql.ConfigRead(wxString::Format("folderscanner/url%i", (int)currSourceIndex), "*")=="*" /*check for existance (`*` is an invalid URL)*/
 		 || currSourceIndex > MAX_DEL /*avoid deadlocks*/ )
 		{
 			break; // done
 		}
 
-		wxString url = sql.ConfigRead(wxString::Format(wxT("folderscanner/url%i"), (int)currSourceIndex), wxT(""));
+		wxString url = sql.ConfigRead(wxString::Format("folderscanner/url%i", (int)currSourceIndex), "");
 
-		sql.ConfigDeleteEntry(wxT("folderscanner/deepupdate/")+url);
-		sql.ConfigDeleteEntry(wxT("folderscanner/trackCount/")+url);
-		sql.ConfigDeleteEntry(wxString::Format(wxT("folderscanner/url%i"), (int)currSourceIndex));
-		sql.ConfigDeleteEntry(wxString::Format(wxT("folderscanner/ignoreExt%i"), (int)currSourceIndex));
-		sql.ConfigDeleteEntry(wxString::Format(wxT("folderscanner/pattern%i"), (int)currSourceIndex));
-		sql.ConfigDeleteEntry(wxString::Format(wxT("folderscanner/flags%i"), (int)currSourceIndex));
+		sql.ConfigDeleteEntry("folderscanner/deepupdate/"+url);
+		sql.ConfigDeleteEntry("folderscanner/trackCount/"+url);
+		sql.ConfigDeleteEntry(wxString::Format("folderscanner/url%i", (int)currSourceIndex));
+		sql.ConfigDeleteEntry(wxString::Format("folderscanner/additionalExt%i", (int)currSourceIndex));
+		sql.ConfigDeleteEntry(wxString::Format("folderscanner/ignoreExt%i", (int)currSourceIndex));
+		sql.ConfigDeleteEntry(wxString::Format("folderscanner/pattern%i", (int)currSourceIndex));
+		sql.ConfigDeleteEntry(wxString::Format("folderscanner/flags%i", (int)currSourceIndex));
 
 		currSourceIndex++;
 	}
@@ -511,7 +528,7 @@ SjFolderScannerSource* SjFolderScannerModule::GetSourceObj__(long index)
 	SjFolderScannerSourceList::Node* currSourceNode = m_listOfSources.Item(index);
 	if( currSourceNode == NULL )
 	{
-		wxLogError(wxT("Cannot get folder source object at index %i.")/*n/t*/, (int)index);
+		wxLogError("Cannot get folder source object at index %i."/*n/t*/, (int)index);
 		return NULL;
 	}
 
@@ -526,7 +543,7 @@ wxString SjFolderScannerModule::GetSourceUrl(long index)
 {
 	SjFolderScannerSource* currSourceObj = GetSourceObj__(index);
 
-	return currSourceObj? currSourceObj->UrlPlusFile() : wxString(wxT(""));
+	return currSourceObj? currSourceObj->UrlPlusFile() : wxString("");
 }
 
 
@@ -564,7 +581,7 @@ wxString SjFolderScannerModule::GetSourceNotes(long index)
 			return _("No update");
 		}
 	}
-	return wxT("");
+	return "";
 }
 
 
@@ -600,7 +617,7 @@ long SjFolderScannerModule::AddSources(int sourceType, wxWindow* parent)
 		// show "select dir" dialog
 		wxDirDialog dirDialog(parent,
 		                      _("Select a folder with music-files"),
-		                      defSource? defSource->m_url : wxString(wxT("")),
+		                      defSource? defSource->m_url : wxString(""),
 		                      wxDD_DEFAULT_STYLE & ~(wxDD_NEW_DIR_BUTTON ));
 		if( dirDialog.ShowModal() != wxID_OK )
 		{
@@ -615,8 +632,8 @@ long SjFolderScannerModule::AddSources(int sourceType, wxWindow* parent)
 		// show "select file" dialog
 		wxFileDialog fileDialog(parent,
 		                        _("Select music-file"),
-		                        defSource? defSource->m_url : wxString(wxT("")),
-		                        wxT(""), g_mainFrame->m_moduleSystem.GetAssignedExt(SJ_EXT_MUSICFILES|SJ_EXT_ARCHIVES).GetFileDlgStr(), wxFD_OPEN|wxFD_CHANGE_DIR);
+		                        defSource? defSource->m_url : wxString(""),
+		                        "", g_mainFrame->m_moduleSystem.GetAssignedExt(SJ_EXT_MUSICFILES|SJ_EXT_ARCHIVES).GetFileDlgStr(), wxFD_OPEN|wxFD_CHANGE_DIR);
 		if( fileDialog.ShowModal() != wxID_OK )
 		{
 			return -1; // nothing added
@@ -656,11 +673,12 @@ long SjFolderScannerModule::DoAddUrl(const wxString& newUrl__, const wxString& n
 
 	// add new source
 	SjFolderScannerSource* currSourceObj = new SjFolderScannerSource;
-	currSourceObj->m_url        = newUrl;
-	currSourceObj->m_file       = newFile;
-	currSourceObj->m_ignoreExt  = (defSource && newFile.IsEmpty())? defSource->m_ignoreExt : SjExtList();
+	currSourceObj->m_url           = newUrl;
+	currSourceObj->m_file          = newFile;
+	currSourceObj->m_additionalExt = (defSource && newFile.IsEmpty())? defSource->m_additionalExt : SjExtList();
+	currSourceObj->m_ignoreExt     = (defSource && newFile.IsEmpty())? defSource->m_ignoreExt : SjExtList();
 	currSourceObj->m_trackInfoMatcher.Compile(SJ_TI_URL, defSource? defSource->m_trackInfoMatcher.GetPattern() : SjTrackInfoMatcher::GetDefaultPattern());
-	currSourceObj->m_flags      = SJ_FOLDERSCANNER_DEFFLAGS;
+	currSourceObj->m_flags         = SJ_FOLDERSCANNER_DEFFLAGS;
 
 	if( !newFile.IsEmpty() )
 	{
@@ -679,7 +697,7 @@ long SjFolderScannerModule::DoAddUrl(const wxString& newUrl__, const wxString& n
 bool SjFolderScannerModule::AddUrl(const wxString& url)
 {
 	bool sthAdded;
-	DoAddUrl(url, wxT(""), sthAdded);
+	DoAddUrl(url, "", sthAdded);
 	return sthAdded;
 }
 
@@ -747,13 +765,6 @@ bool SjFolderScannerModule::IterateFile__(const wxString&        url,
 		goto Cleanup;
 	}
 
-	// check if the current extension can be handled by the player
-	if( !g_mainFrame->m_player.TestUrl(url) )
-	{
-		ret = TRUE; // error, but continue
-		goto Cleanup;
-	}
-
 	// get track information
 	trackInfo = new SjTrackInfo;
 	if( !trackInfo )
@@ -875,7 +886,7 @@ bool SjFolderScannerModule::IterateDir__(const wxString&        url, // may or m
 			if( dirEntryFn.IsOk() && wxDir::Exists(dirEntryStr) )
 			{
 				// ... collect FILES using wxDir (allows us to read HIDDEN files)
-				wxDir::GetAllFiles(dirEntryStr, &fileEntries, wxT("*"),
+				wxDir::GetAllFiles(dirEntryStr, &fileEntries, "*",
 								   wxDIR_FILES
 								   |   ((source->m_flags&SJ_FOLDERSCANNER_READHIDDENFILES)? wxDIR_HIDDEN : 0));
 				FileNamesToURLs(fileEntries);
@@ -886,7 +897,7 @@ bool SjFolderScannerModule::IterateDir__(const wxString&        url, // may or m
 		if( scanUsingFS )
 		{
 			// ... collect FILES using wxFileSystem
-			dirEntryStr = fileSystem.FindFirst(wxT("*"), wxFILE);
+			dirEntryStr = fileSystem.FindFirst("*", wxFILE);
 			while( !dirEntryStr.IsEmpty() )
 			{
 				fileEntries.Add(dirEntryStr);
@@ -907,7 +918,7 @@ bool SjFolderScannerModule::IterateDir__(const wxString&        url, // may or m
 			{
 				wxDir theDir(dirEntryStr);
 				wxString theEntry;
-				bool cont = theDir.GetFirst(&theEntry, wxT("*"),  wxDIR_DIRS
+				bool cont = theDir.GetFirst(&theEntry, "*",  wxDIR_DIRS
 						|   ((source->m_flags&SJ_FOLDERSCANNER_READHIDDENDIRS)? wxDIR_HIDDEN : 0));
 				while ( cont )
 				{
@@ -923,11 +934,11 @@ bool SjFolderScannerModule::IterateDir__(const wxString&        url, // may or m
 		if( scanUsingFS )
 		{
 			// ... collect all DIRECTORIES using wxFileSystem
-			dirEntryStr = fileSystem.FindFirst(wxT("*"), wxDIR);
+			dirEntryStr = fileSystem.FindFirst("*", wxDIR);
 			while( !dirEntryStr.IsEmpty() )
 			{
-				dirEntryStr.Replace(wxT("tar:/"), wxT("tar:")); // THIS IS A HACK!!!
-				dirEntryStr.Replace(wxT("zip:/"), wxT("zip:")); // THIS IS A HACK!!!
+				dirEntryStr.Replace("tar:/", "tar:"); // THIS IS A HACK!!!
+				dirEntryStr.Replace("zip:/", "zip:"); // THIS IS A HACK!!!
 				// the files system returns directories as
 				// "c:/bla/bla.zip#zip:/dir" which must be called
 				// "c:/bla/bla.zip#zip:dir"
@@ -964,7 +975,7 @@ bool SjFolderScannerModule::IterateDir__(const wxString&        url, // may or m
 			if( fsFile )
 			{
 				// add art
-				if( !arts.IsEmpty() ) arts += wxT("\n");
+				if( !arts.IsEmpty() ) arts += "\n";
 				arts += currUrl;
 
 				// set crc
@@ -981,15 +992,15 @@ bool SjFolderScannerModule::IterateDir__(const wxString&        url, // may or m
 		currUrl = fileEntries.Item(entryIndex);
 		currExt = SjTools::GetExt(currUrl);
 
-		if( (source->m_flags&SJ_FOLDERSCANNER_READZIP) && currExt == wxT("zip") )
+		if( (source->m_flags&SJ_FOLDERSCANNER_READZIP) && currExt == "zip" )
 		{
-			subdirEntries.Add(currUrl + wxT("#zip:/"));
+			subdirEntries.Add(currUrl + "#zip:/");
 		}
-		else if( (source->m_flags&SJ_FOLDERSCANNER_READZIP) && currExt == wxT("tar") )
+		else if( (source->m_flags&SJ_FOLDERSCANNER_READZIP) && currExt == "tar" )
 		{
-			subdirEntries.Add(currUrl + wxT("#tar:/"));
+			subdirEntries.Add(currUrl + "#tar:/");
 		}
-		else if( !source->m_ignoreExt.LookupExt(currExt) )
+		else if( source->m_musicExt.LookupExt(currExt) )
 		{
 			// the file is an understood media file
 			if( !IterateFile__(currUrl, deepUpdate, arts, crc32, source, receiver, retTrackCount) )
@@ -1005,7 +1016,7 @@ bool SjFolderScannerModule::IterateDir__(const wxString&        url, // may or m
 	{
 		currUrl = subdirEntries.Item(entryIndex);
 
-		if( !IterateDir__(currUrl, wxT(""), deepUpdate, source, receiver, retTrackCount) )
+		if( !IterateDir__(currUrl, "", deepUpdate, source, receiver, retTrackCount) )
 		{
 			return FALSE; // user abort
 		}
@@ -1022,7 +1033,7 @@ long SjFolderScannerModule::GetTrackCount__(SjFolderScannerSource* source)
 
 	// returns -1 for "don't know"
 	wxSqlt sql;
-	return sql.ConfigRead(wxT("folderscanner/trackCount/")+source->UrlPlusFile(), -1);
+	return sql.ConfigRead("folderscanner/trackCount/"+source->UrlPlusFile(), -1);
 }
 
 
@@ -1043,14 +1054,19 @@ bool SjFolderScannerModule::IterateTrackInfo(SjColModule* receiver)
 
 		if( currSource->m_flags&SJ_FOLDERSCANNER_ENABLED )
 		{
+			// set up the extensions to read
+			currSource->m_musicExt = g_mainFrame->m_moduleSystem.GetAssignedExt(SJ_EXT_MUSICFILES);
+			currSource->m_musicExt.AddExt(currSource->m_additionalExt);
+			currSource->m_musicExt.SubExt(currSource->m_ignoreExt);
+
 			// deep update current source?
 			{
 				wxSqlt sql;
 				doIterateDir = TRUE;
-				deepUpdate = sql.ConfigRead(wxT("folderscanner/deepupdate/")+currSource->UrlPlusFile(), 0)? TRUE : FALSE;
+				deepUpdate = sql.ConfigRead("folderscanner/deepupdate/"+currSource->UrlPlusFile(), 0)? TRUE : FALSE;
 				if( deepUpdate )
 				{
-					sql.ConfigWrite(wxT("folderscanner/deepupdate/")+currSource->UrlPlusFile(), 0L);
+					sql.ConfigWrite("folderscanner/deepupdate/"+currSource->UrlPlusFile(), 0L);
 				}
 			}
 
@@ -1089,7 +1105,7 @@ bool SjFolderScannerModule::IterateTrackInfo(SjColModule* receiver)
 				if( GetTrackCount__(currSource) != trackCount )
 				{
 					wxSqlt sql;
-					sql.ConfigWrite(wxT("folderscanner/trackCount/")+currSource->UrlPlusFile(), trackCount);
+					sql.ConfigWrite("folderscanner/trackCount/"+currSource->UrlPlusFile(), trackCount);
 				}
 			}
 		}
